@@ -1,6 +1,5 @@
 import cfdm
-from numpy import empty as numpy_empty
-from numpy import result_type as numpy_result_type
+import numpy as np
 
 from . import Bounds, mixin
 from .data.data import Data
@@ -114,80 +113,34 @@ class DimensionCoordinate(
         data = self.get_data(None, _fill_value=False)
         if data is not None:
             # Infer the direction from the data
-            if data._size > 1:
-                data = data[0:2].array
-                return bool(
-                    data.item(
-                        0,
-                    )
-                    < data.item(
-                        1,
-                    )
-                )
+            if data.size > 1:
+                c = data._get_cached_elements()
+                if c:
+                    try:
+                        return bool(c.get(0) < c.get(1))
+                    except TypeError:
+                        pass
+
+                data = data[:2].compute()
+                return bool(data.item(0) < data.item(1))
 
         # Still here?
         data = self.get_bounds_data(None, _fill_value=False)
         if data is not None:
             # Infer the direction from the bounds
-            b = data[(0,) * (data.ndim - 1)].array
-            return bool(
-                b.item(
-                    0,
-                )
-                < b.item(
-                    1,
-                )
-            )
+            c = data._get_cached_elements()
+            if c:
+                try:
+                    return bool(c.get(0) < c.get(1))
+                except TypeError:
+                    pass
+
+            b = data[0].compute()
+            return bool(b.item(0) < b.item(1))
 
         # Still here? Then infer the direction from the units.
         return not self.Units.ispressure
 
-    # ----------------------------------------------------------------
-    # Attributes
-    # ----------------------------------------------------------------
-    #    @property
-    #    def cellsize(self):
-    #        '''The cell sizes.
-    #
-    #    :Returns:
-    #
-    #        `Data`
-    #            The size for each cell.
-    #
-    #    **Examples**
-    #
-    #    >>> print(c.bounds)
-    #    <CF Bounds: latitude(3, 2) degrees_north>
-    #    >>> print(c.bounds.array)
-    #    [[-90. -87.]
-    #     [-87. -80.]
-    #     [-80. -67.]]
-    #    >>> print(d.cellsize)
-    #    <CF Data(3): [3.0, 7.0, 13.0] degrees_north>
-    #    >>> print(d.cellsize.array)
-    #    [  3.   7.  13.]
-    #    >>> print(c.sin().cellsize.array)
-    #    [ 0.00137047  0.01382178  0.0643029 ]
-    #
-    #    >>> del(c.bounds)
-    #    >>> c.cellsize
-    #    AttributeError: Can't get cell sizes when coordinates have no bounds
-    #
-    #        '''
-    #        cells = self.get_bounds_data(None)
-    #        if cells is None:
-    #            raise AttributeError(
-    #                "Can't get cell sizes when coordinates have no bounds")
-    #
-    #        if self.direction():
-    #            cells = cells[:, 1] - cells[:, 0]
-    #        else:
-    #            cells = cells[:, 0] - cells[:, 1]
-    #
-    #        cells.squeeze(1, inplace=True)
-    #
-    #        return cells
-
     @property
     def decreasing(self):
         """True if the dimension coordinate is decreasing, otherwise
@@ -246,69 +199,6 @@ class DimensionCoordinate(
         """
         return self.direction()
 
-    #    @property
-    #    def lower_bounds(self):
-    #        '''The lower dimension coordinate bounds in a `cf.Data` object.
-    #
-    #    .. seealso:: `bounds`, `upper_bounds`
-    #
-    #    **Examples**
-    #
-    #    >>> print(c.bounds.array)
-    #    [[ 5  3]
-    #     [ 3  1]
-    #     [ 1 -1]]
-    #    >>> c.lower_bounds
-    #    <CF Data(3): [3, 1, -1]>
-    #    >>> print(c.lower_bounds.array)
-    #    [ 3  1 -1]
-    #
-    #        '''
-    #        data = self.get_bounds_data(None)
-    #        if data is None:
-    #            raise ValueError(
-    #                "Can't get lower bounds when there are no bounds")
-    #
-    #        if self.direction():
-    #            i = 0
-    #        else:
-    #            i = 1
-    #
-    #        out = data[..., i]
-    #        out.squeeze(1, inplace=True)
-    #        return out
-
-    #
-    #    @property
-    #    def upper_bounds(self):
-    #        '''The upper dimension coordinate bounds in a `cf.Data` object.
-    #
-    #    .. seealso:: `bounds`, `lower_bounds`
-    #
-    #    **Examples**
-    #
-    #    >>> print(c.bounds.array)
-    #    [[ 5  3]
-    #     [ 3  1]
-    #     [ 1 -1]]
-    #    >>> c.upper_bounds
-    #    <CF Data(3): [5, 3, 1]>
-    #    >>> print(c.upper_bounds.array)
-    #    [5  3  1]
-    #
-    #        '''
-    #        data = self.get_bounds_data(None)
-    #        if data is None:
-    #            raise ValueError(
-    #                "Can't get upper bounds when there are no bounds")
-    #
-    #        if self.direction():
-    #            i = 1
-    #        else:
-    #            i = 0
-    #
-    #        return data[..., i].squeeze(1)
-
     def direction(self):
         """Return True if the dimension coordinate values are
         increasing, otherwise return False.
@@ -349,160 +239,331 @@ class DimensionCoordinate(
 
         return _direction
 
+    @classmethod
+    def create_regular(cls, args, units=None, standard_name=None, bounds=True):
+        """
+        Create a new `DimensionCoordinate` with the given range and cellsize.
+
+        .. versionadded:: 3.15.0
+
+        :Note: This method does not set the cyclicity of the
+               `DimensionCoordinate`.
+
+        :Parameters:
+
+            args: sequence of numbers
+                A sequence of three numeric values. The first two values in the
+                sequence represent the coordinate range (see the bounds
+                parameter for details), and the third value represents the
+                cellsize.
+
+            bounds: `bool`, optional
+                If True (the default) then the given range represents
+                the bounds, and the coordinate points will be the midpoints of
+                the bounds. If False, the range represents the coordinate points
+                directly.
+
+            units: str or `Units`, optional
+                The units of the new `DimensionCoordinate` object.
+
+            standard_name: str, optional
+                The standard_name of the `DimensionCoordinate` object.
+
+        :Returns:
+
+            `DimensionCoordinate`
+                The newly created DimensionCoordinate object.
+
+        **Examples**
+
+        >>> longitude = cf.DimensionCoordinate.create_regular(
+                (-180, 180, 1), units='degrees_east', standard_name='longitude'
+            )
+        >>> longitude.dump()
+        Dimension coordinate: longitude
+            standard_name = 'longitude'
+            units = 'degrees_east'
+            Data(360) = [-179.5, ..., 179.5] degrees_east
+            Bounds:units = 'degrees_east'
+            Bounds:Data(360, 2) = [[-180.0, ..., 180.0]] degrees_east
+
+        """
+        args = np.array(args)
+
+        if args.shape != (3,) or args.dtype.kind not in "fi":
+            raise ValueError(
+                "The args argument was incorrectly formatted. "
+                f"Expected a sequence of three numbers, got {args}."
+            )
+
+        range = (args[0], args[1])
+        cellsize = args[2]
+
+        range_diff = range[1] - range[0]
+        if cellsize > 0 and range_diff <= 0:
+            raise ValueError(
+                f"Range ({range[0], range[1]}) must be increasing for a "
+                f"positive cellsize ({cellsize})"
+            )
+        elif cellsize < 0 and range_diff >= 0:
+            raise ValueError(
+                f"Range ({range[0], range[1]}) must be decreasing for a "
+                f"negative cellsize ({cellsize})"
+            )
+
+        if range_diff % cellsize != 0:
+            raise ValueError(
+                f"The range of the dimension ({range_diff}) must be "
+                f"divisible by the cellsize ({cellsize})"
+            )
+
+        if standard_name is not None and not isinstance(standard_name, str):
+            raise ValueError("standard_name must be either None or a string.")
+
+        if bounds:
+            cellsize2 = cellsize / 2
+            start = range[0] + cellsize2
+            end = range[1] - cellsize2
+        else:
+            start = range[0]
+            end = range[1]
+
+        points = np.arange(start, end + cellsize, cellsize)
+
+        coordinate = cls(
+            data=Data(points, units=units),
+            properties={"standard_name": standard_name},
+            copy=False,
+        )
+
+        if bounds:
+            b = coordinate.create_bounds()
+            coordinate.set_bounds(b, copy=False)
+
+        return coordinate
+
     def create_bounds(
         self, bound=None, cellsize=None, flt=0.5, max=None, min=None
     ):
         """Create cell bounds.
 
+        Creates new cell bounds, irrespective of whether the cells
+        already have cell bounds. The new bounds are not set on the
+        dimension coordinate construct, but if that is desired they
+        may always be added with the `set_bounds` method, for
+        instance:
+
+        >>> b = d.create_bounds()
+        >>> d.set_bounds(b)
+
+        By default, Voronoi cells are created by defining cell bounds
+        that are half way between adjacent coordinate values. For
+        non-cyclic coordinates, extrapolation is used so that the
+        first and last cells have their coordinates in their centres.
+
+        For instance, the Voronoi cells created for non-cyclic
+        coordinates ``0, 40, 90, 180`` have bounds ``(-20, 20), (20,
+        65), (65, 135), (135, 225)``. If those coordinates were
+        instead cyclic with a period of ``360``, then the bounds would
+        be ``(-90, 20), (20, 65), (65, 135), (135, 270)``.
+
+        .. seealso:: `del_bounds`, `get_bounds`, `set_bounds`
+
         :Parameters:
 
-            bound: optional
+            bound: data_like scalar, optional
                 If set to a value larger (smaller) than the largest
-                (smallest) coordinate value then bounds are created which
-                include this value and for which each coordinate is in the
-                centre of its bounds.
+                (smallest) coordinate value, then bounds are created
+                which include this value and for which each coordinate
+                is in the centre of its bounds. This can be useful for
+                recreating the bounds of vertical coordinates from
+                Earth system models.
+
+                *Parameter example:*
+                  For coordinates ``1, 2, 10``, setting ``bound=0.5``
+                  will result in bounds of ``(0.5, 1.5), (1.5, 2.5),
+                  (2.5, 17.5)``.
+
+                *Parameter example:*
+                  Beware that if *bound* is too large or small, then
+                  some returned bounds values will by physically
+                  incorrect. For coordinates ``1, 2, 10``, the setting
+                  of ``bound=-2`` will result in bounds of ``(-2, 4),
+                  (4, 0), (0, 20)``.
 
             cellsize: optional
-                Define the exact size of each cell that is
-                created. Created cells are allowed to overlap do not have
-                to be contigious. The *cellsize* parameter may be one of:
+                Define the size of each cell that is created. Created
+                cells are allowed to overlap and do not have to be
+                contigious. The *cellsize* parameter may be one of:
 
-                  * A data-like scalar (see below) that defines the cell size,
-                    either in the same units as the coordinates or in the
-                    units provided. Note that in this case, the position of
-                    each coordinate within the its cell is controlled by the
-                    *flt* parameter.
+                * data_like scalar
 
-                    *Parameter example:*
-                        To specify cellsizes of 10, in the same units as the
-                        coordinates: ``cellsize=10``.
+                  Defines the cell size, either in the same units as
+                  the coordinates or in the units provided. Note that
+                  in this case, the position of each coordinate within
+                  the its cell is determined by the *flt* parameter.
 
-                    *Parameter example:*
-                        To specify cellsizes of 1 day: ``cellsize=cf.Data(1,
-                        'day')`` (see `cf.Data` for details).
+            ..
 
-                    *Parameter example:*
-                        For coordinates ``1, 2, 10``, setting ``cellsize=1``
-                        will result in bounds of ``(0.5, 1.5), (1.5, 2.5),
-                        (9.5, 10.5)``.
+                * `cf.TimeDuration`
 
-                    *Parameter example:*
-                        For coordinates ``1, 2, 10`` kilometres, setting
-                        ``cellsize=cf.Data(5000, 'm')`` will result in bounds
-                        of ``(-1.5, 3.5), (-0.5, 4.5), (7.5, 12.5)`` (see
-                        `cf.Data` for details).
+                  A time duration defining the cell size. Only
+                  applicable to reference time coordinates. It is
+                  possible to "anchor" the cell bounds via the
+                  `cf.TimeDuration` instance parameters. For example,
+                  to specify cell size of one calendar month, starting
+                  and ending on the 15th day:
+                  ``cellsize=cf.M(day=15)`` (see `cf.M` for
+                  details). Note that the *flt* parameter is ignored
+                  in this case.
 
-                    *Parameter example:*
-                        For decreasing coordinates ``2, 0, -12`` setting,
-                        ``cellsize=2`` will result in bounds of ``(3, 1),
-                        (1, -1), (-11, -13)``.
-
-                  * A `cf.TimeDuration` defining the cell size. Only
-                    applicable to reference time coordinates. It is possible
-                    to "anchor" the cell bounds via the `cf.TimeDuration`
-                    parameters. For example, to specify cell size of one
-                    calendar month, starting and ending on the 15th day:
-                    ``cellsize=cf.M(day=15)`` (see `cf.M` for details). Note
-                    that the *flt* parameter is ignored in this case.
-
-                    *Parameter example:*
-                        For coordinates ``1984-12-01 12:00, 1984-12-02
-                        12:00, 2000-04-15 12:00`` setting,
-                        ``cellsize=cf.D()`` will result in bounds of
-                        ``(1984-12-01, 1984-12-02), (1984-12-02,
-                        1984-12-03), (2000-05-15, 2000-04-16)`` (see `cf.D`
-                        for details).
-
-                    *Parameter example:*
-                        For coordinates ``1984-12-01, 1984-12-02,
-                        2000-04-15`` setting, ``cellsize=cf.D()`` will
-                        result in bounds of ``(1984-12-01, 1984-12-02),
-                        (1984-12-02, 1984-12-03), (2000-05-15, 2000-04-16)``
-                        (see `cf.D` for details).
-
-                    *Parameter example:*
-                        For coordinates ``1984-12-01, 1984-12-02,
-                        2000-04-15`` setting, ``cellsize=cf.D(hour=12)``
-                        will result in bounds of ``(1984-11:30 12:00,
-                        1984-12-01 12:00), (1984-12-01 12:00, 1984-12-02
-                        12:00), (2000-05-14 12:00, 2000-04-15 12:00)`` (see
-                        `cf.D` for details).
-
-                    *Parameter example:*
-                        For coordinates ``1984-12-16 12:00, 1985-01-16
-                        12:00`` setting, ``cellsize=cf.M()`` will result in
-                        bounds of ``(1984-12-01, 1985-01-01), (1985-01-01,
-                        1985-02-01)`` (see `cf.M` for details).
-
-                    *Parameter example:*
-                        For coordinates ``1984-12-01 12:00, 1985-01-01
-                        12:00`` setting, ``cellsize=cf.M()`` will result in
-                        bounds of ``(1984-12-01, 1985-01-01), (1985-01-01,
-                        1985-02-01)`` (see `cf.M` for details).
-
-                    *Parameter example:*
-                        For coordinates ``1984-12-01 12:00, 1985-01-01
-                        12:00`` setting, ``cellsize=cf.M(day=20)`` will
-                        result in bounds of ``(1984-11-20, 1984-12-20),
-                        (1984-12-20, 1985-01-20)`` (see `cf.M` for details).
-
-                    *Parameter example:*
-                        For coordinates ``1984-03-01, 1984-06-01`` setting,
-                        ``cellsize=cf.Y()`` will result in bounds of
-                        ``(1984-01-01, 1985-01-01), (1984-01-01,
-                        1985-01-01)`` (see `cf.Y` for details). Note that in
-                        this case each cell has the same bounds. This
-                        because ``cf.Y()`` is equivalent to ``cf.Y(month=1,
-                        day=1)`` and the closest 1st January to both
-                        coordinates is 1st January 1984.
-
-                {+data-like-scalar} TODO
-
-            flt: `float`, optional
-                When creating cells with sizes specified by the *cellsize*
-                parameter, define the fraction of the each cell which is
-                less its coordinate value. By default *flt* is 0.5, so that
-                each cell has its coordinate at it's centre. Ignored if
-                *cellsize* is not set.
+            flt: array_like scalar, optional
+                When creating cells with sizes specified by the
+                *cellsize* parameter, define the fraction of each
+                cell which is less than its coordinate value. By default
+                *flt* is 0.5, so that each cell has its coordinate at
+                its centre. Ignored if *cellsize* is not set.
 
                 *Parameter example:*
-                    For coordinates ``1, 2, 10``, setting ``cellsize=1,
-                    flt=0.5`` will result in bounds of ``(0.5, 1.5), (1.5,
-                    2.5), (9.5, 10.5)``.
+                  For coordinates ``1, 2, 10`` setting ``flt=0.25``
+                  will result in bounds of ``(0.75, 1.75), (1.75,
+                  2.75), (9.75, 10.75)``.
 
                 *Parameter example:*
-                    For coordinates ``1, 2, 10``, setting ``cellsize=1,
-                    flt=0.25`` will result in bounds of ``(0.75, 1.75),
-                    (1.75, 2.75), (9.75, 10.75)``.
+                  For decreasing coordinates ``2, 0, -12``, setting
+                  ``cellsize=6, flt=0.9`` will result in bounds of
+                  ``(2.6, -3.4), (0.6, -5.4), (-11.4, -17.4)``.
 
-                *Parameter example:*
-                    For decreasing coordinates ``2, 0, -12``, setting
-                    ``cellsize=6, flt=0.9`` will result in bounds of
-                    ``(2.6, -3.4), (0.6, -5.4), (-11.4, -17.4)``.
-
-            max: optional
+            max: data_like scalar, optional
                 Limit the created bounds to be no more than this number.
 
                 *Parameter example:*
-                    To ensure that all latitude bounds are at most 90:
-                    ``max=90``.
+                  To ensure that all latitude bounds are at most
+                  ``90``: ``max=90``, or ``max=cf.Data(90,
+                  'degrees_north')``.
 
-            min: optional
+            min: data_like scalar, optional
                 Limit the created bounds to be no less than this number.
 
                 *Parameter example:*
-                    To ensure that all latitude bounds are at least -90:
-                    ``min=-90``.
+                  To ensure that all latitude bounds are at least
+                  ``-90``: ``min=-90``, or ``min=cf.Data(-90,
+                  'degrees_north')``.
 
         :Returns:
 
             `Bounds`
-                The newly-created coordinate cell bounds object.
+                The new coordinate cell bounds.
 
         **Examples**
 
-        >>> c.create_bounds()
-        >>> c.create_bounds(bound=-9000.0)
+        Create bounds for Voronoi cells:
+
+        >>> d = cf.DimensionCoordinate(data=[0.0, 40, 90, 180])
+        >>> b = d.create_bounds()
+        >>> print(b.array)
+        [[-20.  20.]
+         [ 20.  65.]
+         [ 65. 135.]
+         [135. 225.]]
+        >>> d = d[::-1]
+        >>> b = d.create_bounds()
+        >>> print(b.array)
+        [[225. 135.]
+         [135.  65.]
+         [ 65.  20.]
+         [ 20. -20.]]
+
+        Cyclic coordinates have a co-located first and last bound:
+
+        >>> d.period(360)
+        >>> d.cyclic(0)
+        set()
+        >>> b = d.create_bounds()
+        >>> print(b.array)
+        [[270. 135.]
+         [135.  65.]
+         [ 65.  20.]
+         [ 20. -90.]]
+
+        Cellsize units must be equivalent to the coordinate units, or
+        if the cell has no units then they are assumed to be the
+        same as the coordinates:
+
+        >>> d = cf.DimensionCoordinate(data=cf.Data([0, 2, 4], 'km'))
+        >>> b = d.create_bounds(cellsize=cf.Data(2000, 'm'))
+        >>> print(b.array)
+        [[-1  1]
+         [ 1  3]
+         [ 3  5]]
+        >>> b = d.create_bounds(cellsize=2)
+        >>> print(b.array)
+        [[-1  1]
+         [ 1  3]
+         [ 3  5]]
+
+        Cells may be non-contiguous and may overlap:
+
+        >>> d = cf.DimensionCoordinate(data=[1.0, 2, 10])
+        >>> b = d.create_bounds(cellsize=1)
+        >>> print(b.array)
+        [[ 0.5  1.5]
+         [ 1.5  2.5]
+         [ 9.5 10.5]]
+        >>> b = d.create_bounds(cellsize=5)
+        >>> print(b.array)
+        [[-1.5  3.5]
+         [-0.5  4.5]
+         [ 7.5 12.5]]
+
+        Reference date-time coordinates can use `cf.TimeDuration` cell
+        sizes:
+
+        >>> d = cf.DimensionCoordinate(
+        ...   data=cf.Data(['1984-12-01', '1984-12-02'], dt=True)
+        ... )
+        >>> b = d.create_bounds(cellsize=cf.D())
+        >>> print(b.datetime_array)
+        [[cftime.DatetimeGregorian(1984, 12, 1, 0, 0, 0, 0)
+          cftime.DatetimeGregorian(1984, 12, 2, 0, 0, 0, 0)]
+         [cftime.DatetimeGregorian(1984, 12, 2, 0, 0, 0, 0)
+          cftime.DatetimeGregorian(1984, 12, 3, 0, 0, 0, 0)]]
+        >>> b = d.create_bounds(cellsize=cf.D(hour=12))
+        >>> print(b.datetime_array)
+        [[cftime.DatetimeGregorian(1984, 11, 30, 12, 0, 0, 0)
+          cftime.DatetimeGregorian(1984, 12, 1, 12, 0, 0, 0)]
+         [cftime.DatetimeGregorian(1984, 12, 1, 12, 0, 0, 0)
+          cftime.DatetimeGregorian(1984, 12, 2, 12, 0, 0, 0)]]
+
+        Cell bounds defined by calendar months:
+
+        >>> d = cf.DimensionCoordinate(
+        ...   data=cf.Data(['1985-01-16: 12:00', '1985-02-15'], dt=True)
+        ... )
+        >>> b = d.create_bounds(cellsize=cf.M())
+        >>> print(b.datetime_array)
+        [[cftime.DatetimeGregorian(1985, 1, 1, 0, 0, 0, 0)
+          cftime.DatetimeGregorian(1985, 2, 1, 0, 0, 0, 0)]
+         [cftime.DatetimeGregorian(1985, 2, 1, 0, 0, 0, 0)
+          cftime.DatetimeGregorian(1985, 3, 1, 0, 0, 0, 0)]]
+        >>> b = d.create_bounds(cellsize=cf.M(day=20))
+        >>> print(b.datetime_array)
+        [[cftime.DatetimeGregorian(1984, 12, 20, 0, 0, 0, 0
+          cftime.DatetimeGregorian(1985, 1, 20, 0, 0, 0, 0]
+         [cftime.DatetimeGregorian(1985, 1, 20, 0, 0, 0, 0
+          cftime.DatetimeGregorian(1985, 2, 20, 0, 0, 0, 0]]
+
+        Cell bounds defined by calendar years:
+
+        >>> d = cf.DimensionCoordinate(
+        ...   data=cf.Data(['1984-06-01', '1985-06-01'], dt=True)
+        ... )
+        >>> b = d.create_bounds(cellsize=cf.Y(month=12))
+        >>> print(b.datetime_array)
+        [[cftime.DatetimeGregorian(1983, 12, 1, 0, 0, 0, 0)
+          cftime.DatetimeGregorian(1984, 12, 1, 0, 0, 0, 0)]
+         [cftime.DatetimeGregorian(1984, 12, 1, 0, 0, 0, 0)
+          cftime.DatetimeGregorian(1985, 12, 1, 0, 0, 0, 0)]]
 
         """
         array = self.array
@@ -545,7 +606,7 @@ class DimensionCoordinate(
                 if not self.direction():
                     cellsize0, cellsize1 = -cellsize1, -cellsize0
 
-                bounds = numpy_empty((size, 2), dtype=array.dtype)
+                bounds = np.empty((size, 2), dtype=array.dtype)
                 bounds[:, 0] = array - cellsize0
                 bounds[:, 1] = array + cellsize1
             else:
@@ -570,7 +631,7 @@ class DimensionCoordinate(
                         f"non-reference time coordinates: {self.Units!r}"
                     )
 
-                bounds = numpy_empty((size, 2), dtype=object)
+                bounds = np.empty((size, 2), dtype=object)
 
                 cellsize_bounds = cellsize.bounds
                 direction = bool(self.direction())
@@ -584,44 +645,44 @@ class DimensionCoordinate(
                 # ----------------------------------------------------
                 if size < 2:
                     raise ValueError(
-                        "Can't create bounds for Voronoi cells from one value"
+                        "Can't create Voronoi bounds when there is "
+                        "only one cell"
                     )
 
-                bounds_1d = [
-                    array.item(
-                        0,
-                    )
-                    * 1.5
-                    - array.item(
-                        1,
-                    )
-                    * 0.5
-                ]
+                bounds_1d = [array.item(0) * 1.5 - array.item(1) * 0.5]
                 bounds_1d.extend((array[0:-1] + array[1:]) * 0.5)
-                bounds_1d.append(
-                    array.item(
-                        -1,
-                    )
-                    * 1.5
-                    - array.item(
-                        -2,
-                    )
-                    * 0.5
-                )
+                bounds_1d.append(array.item(-1) * 1.5 - array.item(-2) * 0.5)
 
                 dtype = type(bounds_1d[0])
 
-                if max is not None:
-                    if self.direction():
-                        bounds_1d[-1] = max
-                    else:
-                        bounds_1d[0] = max
-                if min is not None:
-                    if self.direction():
-                        bounds_1d[0] = min
-                    else:
-                        bounds_1d[-1] = min
+                if self.cyclic():
+                    period = self.period()
+                    if period is None:
+                        raise ValueError(
+                            "Can't create Voronoi bounds for cyclic "
+                            "coordinates with no period"
+                        )
 
+                    if self.direction():
+                        # Increasing
+                        b = 0.5 * (array[0] + period - array[-1])
+                    else:
+                        # Decreasing
+                        b = 0.5 * (array[-1] - period + array[0])
+
+                    bounds_1d[0] = array.item(0) - b
+                    bounds_1d[-1] = array.item(-1) + b
+                else:
+                    if max is not None:
+                        if self.direction():
+                            bounds_1d[-1] = max
+                        else:
+                            bounds_1d[0] = max
+                    if min is not None:
+                        if self.direction():
+                            bounds_1d[0] = min
+                        else:
+                            bounds_1d[-1] = min
             else:
                 # ----------------------------------------------------
                 # Create
@@ -631,29 +692,13 @@ class DimensionCoordinate(
                     array = array[::-1]
 
                 bounds_1d = [bound]
-                if bound <= array.item(
-                    0,
-                ):
+                if bound <= array.item(0):
                     for i in range(size):
-                        bound = (
-                            2.0
-                            * array.item(
-                                i,
-                            )
-                            - bound
-                        )
+                        bound = 2.0 * array.item(i) - bound
                         bounds_1d.append(bound)
-                elif bound >= array.item(
-                    -1,
-                ):
+                elif bound >= array.item(-1):
                     for i in range(size - 1, -1, -1):
-                        bound = (
-                            2.0
-                            * array.item(
-                                i,
-                            )
-                            - bound
-                        )
+                        bound = 2.0 * array.item(i) - bound
                         bounds_1d.append(bound)
 
                     bounds_1d = bounds_1d[::-1]
@@ -665,7 +710,7 @@ class DimensionCoordinate(
                 if not direction:
                     bounds_1d = bounds_1d[::-1]
 
-            bounds = numpy_empty((size, 2), dtype=dtype)
+            bounds = np.empty((size, 2), dtype=dtype)
             bounds[:, 0] = bounds_1d[:-1]
             bounds[:, 1] = bounds_1d[1:]
 
@@ -674,7 +719,7 @@ class DimensionCoordinate(
 
         return bounds
 
-    @_deprecated_kwarg_check("i")
+    @_deprecated_kwarg_check("i", version="3.0.0", removed_at="4.0.0")
     @_inplace_enabled(default=False)
     def flip(self, axes=None, inplace=False, i=False):
         """Flips the dimension coordinate, that is reverses its
@@ -801,7 +846,7 @@ class DimensionCoordinate(
     #
     #        return True
 
-    @_deprecated_kwarg_check("i")
+    @_deprecated_kwarg_check("i", version="3.0.0", removed_at="4.0.0")
     @_inplace_enabled(default=False)
     def roll(self, axis, shift, inplace=False, i=False):
         """Rolls the dimension coordinate along a cyclic axis."""
@@ -836,35 +881,37 @@ class DimensionCoordinate(
 
         super(DimensionCoordinate, c).roll(axis, shift, inplace=True)
 
-        c.dtype = numpy_result_type(c.dtype, period.dtype)
+        c.dtype = np.result_type(c.dtype, period.dtype)
+
+        data = c.data
 
         b = c.get_bounds(None)
         bounds_data = c.get_bounds_data(None, _fill_value=False)
 
         if bounds_data is not None:
-            b.dtype = numpy_result_type(bounds_data.dtype, period.dtype)
+            b.dtype = np.result_type(bounds_data.dtype, period.dtype)
             bounds_data = b.get_data(None, _fill_value=False)
 
         if direction:
             # Increasing
-            c[:shift] -= period
+            data[:shift] -= period
             if bounds_data is not None:
-                b[:shift] -= period
+                bounds_data[:shift] -= period
 
-            if c.data[0] <= centre - period:
-                c += period
+            if data[0] <= centre - period:
+                data += period
                 if bounds_data is not None:
-                    b += period
+                    bounds_data += period
         else:
             # Decreasing
-            c[:shift] += period
+            data[:shift] += period
             if bounds_data is not None:
-                b[:shift] += period
+                bounds_data[:shift] += period
 
-            if c.data[0] >= centre + period:
-                c -= period
+            if data[0] >= centre + period:
+                data -= period
                 if bounds_data is not None:
-                    b -= period
+                    bounds_data -= period
 
         c._custom["direction"] = direction
 
@@ -878,5 +925,9 @@ class DimensionCoordinate(
         """Deprecated at version 3.0.0, use `construct_type` attribute
         instead."""
         _DEPRECATION_ERROR_ATTRIBUTE(
-            self, "role", "Use attribute 'construct_type' instead"
+            self,
+            "role",
+            "Use attribute 'construct_type' instead",
+            version="3.0.0",
+            removed_at="4.0.0",
         )  # pragma: no cover
