@@ -483,14 +483,20 @@ _docstring_substitution_definitions = {
                 If True (the default) then alter any bounds.""",
     # cull
     "{{cull_graph: `bool`, optional}}": """cull_graph: `bool`, optional
-                By default *cull_graph* is True, meaning that
-                unnecessary tasks are removed (culled) from each
-                array's dask graph before concatenation. This process
-                has a small overhead but can improve performance
-                overall. If set to False then dask graphs are not
-                culled. See `dask.optimization.cull` for details.
-
-                .. versionadded:: 3.14.0""",
+                If True then unnecessary tasks are removed (culled)
+                from each array's dask graph before
+                concatenation. This process can have a considerable
+                overhead but can sometimes improve the overall
+                performance of a workflow. If False (the default) then
+                dask graphs are not culled. See
+                `dask.optimization.cull` for details.""",
+    # relaxed_units
+    "{{relaxed_units: `bool`, optional}}": """relaxed_units: `bool`, optional
+                If True then allow the concatenation of data with
+                invalid but otherwise equal units. By default, if any
+                data array has invalid units then the concatenation
+                will fail. A `Units` object is considered to be
+                invalid if its `!isvalid` attribute is `False`.""",
     # cfa substitutions
     "{{cfa substitutions: `dict`}}": """substitutions: `dict`
                 The substitution definitions in a dictionary whose
